# Utlity-python-library
These library just need to use pip install to download, no need to download extra exe or on git. (Sacrifice the accuracy for easy implement) Place to store some function that might be used. If you too lazy to write function and set up, just call the function in file.
Each file is designed to be independent, so you could copy the file and put to use without needing to get another file with it.


> **Inspiration:** This project was inspired by the github repository:
> [awesome-python](https://github.com/vinta/awesome-python)
